% 0----------------------------------------------------------------------0
% | Program plotTransient.m                                              |
% | Used to plot properties of flow in the transient system.             |
% | conditions.                                                          |
% | Uses data from:                                                      |
% |     tr(#1).mat                                                       |
% |     ...                                                              |
% |     tr(#n).mat                                                       |
% |     ssD400.mat                                                       |
% |     initdata.mat                                                     |
% | Saves figures in:                                                    |
% |     V_(...).eps                                                      |
% |     p_(...).eps                                                      |
% |                                                                      |
% | Coded by:                                                            |
% |     Stud. Techn. Eivind Vrlstad,                                    |
% |     Institutt for Energi- og prosessteknikk, NTNU, 2011              |
% 0----------------------------------------------------------------------0

clear all
clc

load('../initdata')
load('trNL2030s2615bar.mat')
load('trDO2030s2615bar.mat')
load('../Steadystate/ssD400')

t = t_trNL2030s2615bar;
N = length(t);
t_step = (N-1)/ceil(max(t));

t_int = 0:10:80;

p_well = [p_trDO2030s2615bar(1,:)*1E-5; ...
          p_trNL2030s2615bar(1,:)*1E-5];
p_head = [p_trDO2030s2615bar(2,:)*1E-5; ...
          p_trNL2030s2615bar(2,:)*1E-5];
p_top  = [p_trDO2030s2615bar(4,:)*1E-5; ...
          p_trNL2030s2615bar(4,:)*1E-5];


V_well = [V_trDO2030s2615bar(1,:); ...
          V_trNL2030s2615bar(1,:)];
V_head = [V_trDO2030s2615bar(2,:); ...
          V_trNL2030s2615bar(2,:)];
V_top  = [V_trDO2030s2615bar(4,:); ...
          V_trNL2030s2615bar(4,:)];


Q_0_well = [Q_0_trDO2030s2615bar(1,:); ...
          Q_0_trNL2030s2615bar(1,:)];
Q_0_head = [Q_0_trDO2030s2615bar(2,:); ...
          Q_0_trNL2030s2615bar(2,:)];
Q_0_top  = [Q_0_trDO2030s2615bar(4,:); ...
          Q_0_trNL2030s2615bar(4,:)];

i = 0;
for valvet1 = 20
    for valvet2 = 30
        i = i+1;
        disp(['Case ' num2str(i)])
        disp(['t_valve_1 = ' num2str(valvet1) ' s, t_valve_2 = ' num2str(valvet2) ' bar'])
        
        
        
        disp(' ')
        for j = t_int
            disp(['p_well, ' num2str(j) ' s = ' num2str(p_well(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        for j = t_int
            disp(['p_head, ' num2str(j) ' s = ' num2str(p_head(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        for j = t_int
            disp(['p_top, ' num2str(j) ' s = ' num2str(p_top(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        
        
        
        disp(' ')
        for j = t_int
            disp(['V_well, ' num2str(j) ' s = ' num2str(V_well(i,1+t_step*j)) ' m/s'])
        end
        [V_well_max I] = max(V_well(i,:));
        disp(['max(V_well) = ' num2str(V_well_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        for j = t_int
            disp(['V_head, ' num2str(j) ' s = ' num2str(V_head(i,1+t_step*j)) ' m/s'])
        end
        [V_head_max I] = max(V_head(i,:));
        disp(['max(V_head) = ' num2str(V_head_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        for j = t_int
            disp(['V_top, ' num2str(j) ' s = ' num2str(V_top(i,1+t_step*j)) ' m/s'])
        end
        [V_top_max I] = max(V_top(i,:));
        disp(['max(V_top) = ' num2str(V_top_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        
        
        
        disp(' ')
        for j = t_int
            disp(['Q_0_well, ' num2str(j) ' s = ' num2str(Q_0_well(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        for j = t_int
            disp(['Q_0_head, ' num2str(j) ' s = ' num2str(Q_0_head(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        for j = t_int
            disp(['Q_0_top, ' num2str(j) ' s = ' num2str(Q_0_top(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        
        
        
        disp(' ')
    end
end


% Diplaying everything in LaTeX code, for easy implementation in the report

i = 0;
disp('LaTeX code:')
disp(' ')
for valvet1 = 20
    for valvet2 =30
        i = i+1;
        disp(['Case ' num2str(i)])
        disp(['t_valve_1 = ' num2str(valvet1) ' s, t_valve_2 = ' num2str(valvet2) ' bar'])
        
        
        
        disp(' ')
        for j = t_int
            disp([num2str(j) '  \t&' ...
                num2str(floor(p_well(i,1+t_step*j))) '&' ...
                num2str(round(10*(p_well(i,1+t_step*j)-floor(p_well(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(p_head(i,1+t_step*j))) '&' ...
                num2str(round(10*(p_head(i,1+t_step*j)-floor(p_head(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(p_top(i,1+t_step*j))) '&' ...
                num2str(round(10*(p_top(i,1+t_step*j)-floor(p_top(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(V_well(i,1+t_step*j))) '&' ...
                num2str(round(100*(V_well(i,1+t_step*j)-floor(V_well(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(V_head(i,1+t_step*j))) '&' ...
                num2str(round(100*(V_head(i,1+t_step*j)-floor(V_head(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(V_top(i,1+t_step*j))) '&' ...
                num2str(round(100*(V_top(i,1+t_step*j)-floor(V_top(i,1+t_step*j))))) '  \t&' ...
                num2str(floor(Q_0_top(i,1+t_step*j))) '&' ...
                num2str(round(1000*(Q_0_top(i,1+t_step*j)-floor(Q_0_top(i,1+t_step*j))))) '\\' ...
                ])
        end
        disp(' ')
    end
end

figure(1)
clf
subplot(2,1,1)
hold on
plot(t_trDO2030s2615bar(1,:),V_trDO2030s2615bar(2,:),'k-.','LineWidth',1)
plot(t_trNL2030s2615bar(1,:),V_trNL2030s2615bar(2,:),'k','LineWidth',1)
hold off
title('Head velocities at different valve times')
xlabel('Time [s]')
ylabel('V_{head} [m/s]')

subplot(2,1,2)
hold on
plot(t_trDO2030s2615bar(1,:),V_trDO2030s2615bar(4,:),'k-.','LineWidth',1)
plot(t_trNL2030s2615bar(1,:),V_trNL2030s2615bar(4,:),'k','LineWidth',1)
hold off
title('Top velocities at different valve times')
xlabel('Time [s]')
ylabel('V_{top} [m/s]')
legend('Double Linear opening', ...
    'Double non-linear opening', ...
    'location','SouthEast')

print -depsc2 ../plots/V_NonlinearOpening

figure(2)
clf
subplot(2,1,1)
hold on
plot(t_trDO2030s2615bar(1,:),p_trDO2030s2615bar(2,:)*1E-5,'k-.','LineWidth',1)
plot(t_trNL2030s2615bar(1,:),p_trNL2030s2615bar(2,:)*1E-5,'k','LineWidth',1)
hold off
title('Head pressures at different valve times')
xlabel('Time [s]')
ylabel('p_{head} [bara]')
legend('Double Linear opening', ...
    'Double non-linear opening', ...
    'location','SouthWest')

subplot(2,1,2)
hold on
plot(t_trDO2030s2615bar(1,:),p_trDO2030s2615bar(4,:)*1E-5,'k-.','LineWidth',1)
plot(t_trNL2030s2615bar(1,:),p_trNL2030s2615bar(4,:)*1E-5,'k','LineWidth',1)
hold off
title('Top pressures at different valve times')
xlabel('Time [s]')
ylabel('p_{top} [bara]')

print -depsc2 ../plots/p_NonlinearOpening