% 0----------------------------------------------------------------------0
% | Program plotTransient.m                                              |
% | Used to plot properties of flow in the transient system.             |
% | conditions.                                                          |
% | Uses data from:                                                      |
% |     tr(#1).mat                                                       |
% |     ...                                                              |
% |     tr(#n).mat                                                       |
% |     ssD400.mat                                                       |
% |     initdata.mat                                                     |
% | Saves figures in:                                                    |
% |     V_(...).eps                                                      |
% |     p_(...).eps                                                      |
% |                                                                      |
% | Coded by:                                                            |
% |     Stud. Techn. Eivind Vrlstad,                                    |
% |     Institutt for Energi- og prosessteknikk, NTNU, 2011              |
% 0----------------------------------------------------------------------0

clear all
clc

load('initdata')
load('trVt10s20bar/trVt10s20bar.mat')
load('trVt10s15bar/trVt10s15bar.mat')
load('trVt20s20bar/trVt20s20bar.mat')
load('trVt20s15bar/trVt20s15bar.mat')
load('ssD400/ssD400')

t = t_trVt10s20bar;
N = length(t);
t_step = (N-1)/ceil(max(t));


p_well = [p_trVt10s15bar(1,:)*1E-5; ...
          p_trVt10s20bar(1,:)*1E-5; ...
          p_trVt20s15bar(1,:)*1E-5; ...
          p_trVt20s20bar(1,:)*1E-5];
p_head = [p_trVt10s15bar(2,:)*1E-5; ...
          p_trVt10s20bar(2,:)*1E-5; ...
          p_trVt20s15bar(2,:)*1E-5; ...
          p_trVt20s20bar(2,:)*1E-5];
p_top  = [p_trVt10s15bar(4,:)*1E-5; ...
          p_trVt10s20bar(4,:)*1E-5; ...
          p_trVt20s15bar(4,:)*1E-5; ...
          p_trVt20s20bar(4,:)*1E-5];


V_well = [V_trVt10s15bar(1,:); ...
          V_trVt10s20bar(1,:); ...
          V_trVt20s15bar(1,:); ...
          V_trVt20s20bar(1,:)];
V_head = [V_trVt10s15bar(2,:); ...
          V_trVt10s20bar(2,:); ...
          V_trVt20s15bar(2,:); ...
          V_trVt20s20bar(2,:)];
V_top  = [V_trVt10s15bar(4,:); ...
          V_trVt10s20bar(4,:); ...
          V_trVt20s15bar(4,:); ...
          V_trVt20s20bar(4,:)];


Q_0_well = [Q_0_trVt10s15bar(1,:); ...
          Q_0_trVt10s20bar(1,:); ...
          Q_0_trVt20s15bar(1,:); ...
          Q_0_trVt20s20bar(1,:)];
Q_0_head = [Q_0_trVt10s15bar(2,:); ...
          Q_0_trVt10s20bar(2,:); ...
          Q_0_trVt20s15bar(2,:); ...
          Q_0_trVt20s20bar(2,:)];
Q_0_top  = [Q_0_trVt10s15bar(4,:); ...
          Q_0_trVt10s20bar(4,:); ...
          Q_0_trVt20s15bar(4,:); ...
          Q_0_trVt20s20bar(4,:)];

i = 0;
for valvet = [10 20]
    for valvep = [15 20]
        i = i+1;
        disp(['Case ' num2str(i)])
        disp(['t_valve = ' num2str(valvet) ' s, p_valve = ' num2str(valvep) ' bar'])
        
        
        
        disp(' ')
        for j = 0:10:40
            disp(['p_well, ' num2str(j) ' s = ' num2str(p_well(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        for j = 0:10:40
            disp(['p_head, ' num2str(j) ' s = ' num2str(p_head(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        for j = 0:10:40
            disp(['p_top, ' num2str(j) ' s = ' num2str(p_top(i,1+t_step*j)) ' bar'])
        end
        disp(' ')
        
        
        
        disp(' ')
        for j = 0:10:40
            disp(['V_well, ' num2str(j) ' s = ' num2str(V_well(i,1+t_step*j)) ' m/s'])
        end
        [V_well_max I] = max(V_well(i,:));
        disp(['max(V_well) = ' num2str(V_well_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        for j = 0:10:40
            disp(['V_head, ' num2str(j) ' s = ' num2str(V_head(i,1+t_step*j)) ' m/s'])
        end
        [V_head_max I] = max(V_head(i,:));
        disp(['max(V_head) = ' num2str(V_head_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        for j = 0:10:40
            disp(['V_top, ' num2str(j) ' s = ' num2str(V_top(i,1+t_step*j)) ' m/s'])
        end
        [V_top_max I] = max(V_top(i,:));
        disp(['max(V_top) = ' num2str(V_top_max) ' @ t = ' num2str(t(I)) ' s'])
        disp(' ')
        
        
        disp(' ')
        for j = 0:10:40
            disp(['Q_0_well, ' num2str(j) ' s = ' num2str(Q_0_well(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        for j = 0:10:40
            disp(['Q_0_head, ' num2str(j) ' s = ' num2str(Q_0_head(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        for j = 0:10:40
            disp(['Q_0_top, ' num2str(j) ' s = ' num2str(Q_0_top(i,1+t_step*j)) ' m^3/s'])
        end
        disp(' ')
        
        
        
        disp(' ')
    end
end


figure(1)
clf
subplot(2,1,1)
hold on
plot(t_trVt10s20bar(1,:),V_trVt10s20bar(2,:),'k:','LineWidth',1)
plot(t_trVt10s15bar(1,:),V_trVt10s15bar(2,:),'k-.','LineWidth',1)
plot(t_trVt20s20bar(1,:),V_trVt20s20bar(2,:),'k--','LineWidth',1)
plot(t_trVt20s15bar(1,:),V_trVt20s15bar(2,:),'k','LineWidth',1)
hold off
title('Head velocities at different valve pressures and times')
xlabel('Time [s]')
ylabel('V_{head} [m/s]')

subplot(2,1,2)
hold on
plot(t_trVt10s20bar(1,:),V_trVt10s20bar(4,:),'k:','LineWidth',1)
plot(t_trVt10s15bar(1,:),V_trVt10s15bar(4,:),'k-.','LineWidth',1)
plot(t_trVt20s20bar(1,:),V_trVt20s20bar(4,:),'k--','LineWidth',1)
plot(t_trVt20s15bar(1,:),V_trVt20s15bar(4,:),'k','LineWidth',1)
hold off
title('Top velocities at different valve pressures and times')
xlabel('Time [s]')
ylabel('V_{top} [m/s]')
legend('t_{valve} = 10 s, p_{top} = 20 bar', ...
    't_{valve} = 10 s, p_{top} = 15 bar', ...
    't_{valve} = 20 s, p_{top} = 20 bar', ...
    't_{valve} = 20 s, p_{top} = 15 bar', ...
    'location','SouthEast')

print -depsc2 ../plots/V_SingleLinearOpening

figure(2)
clf
subplot(2,1,1)
hold on
plot(t_trVt10s20bar(1,:),p_trVt10s20bar(2,:)*1E-5,'k:','LineWidth',1)
plot(t_trVt10s15bar(1,:),p_trVt10s15bar(2,:)*1E-5,'k-.','LineWidth',1)
plot(t_trVt20s20bar(1,:),p_trVt20s20bar(2,:)*1E-5,'k--','LineWidth',1)
plot(t_trVt20s15bar(1,:),p_trVt20s15bar(2,:)*1E-5,'k','LineWidth',1)
hold off
title('Head pressures at different valve pressures and times')
xlabel('Time [s]')
ylabel('p_{head} [bara]')

subplot(2,1,2)
hold on
plot(t_trVt10s20bar(1,:),p_trVt10s20bar(4,:)*1E-5,'k:','LineWidth',1)
plot(t_trVt10s15bar(1,:),p_trVt10s15bar(4,:)*1E-5,'k-.','LineWidth',1)
plot(t_trVt20s20bar(1,:),p_trVt20s20bar(4,:)*1E-5,'k--','LineWidth',1)
plot(t_trVt20s15bar(1,:),p_trVt20s15bar(4,:)*1E-5,'k','LineWidth',1)
hold off
title('Top pressures at different valve pressures and times')
xlabel('Time [s]')
ylabel('p_{top} [bara]')
legend('t_{valve} = 10 s, p_{top} = 20 bar', ...
    't_{valve} = 10 s, p_{top} = 15 bar', ...
    't_{valve} = 20 s, p_{top} = 20 bar', ...
    't_{valve} = 20 s, p_{top} = 15 bar', ...
    'location','NorthEast')

print -depsc2 ../plots/p_SingleLinearOpening