% 0----------------------------------------------------------------------0
% | Program plotsteadystate.m                                            |
% | Used to plot properties of flow in the system at steady-state        |
% | conditions.                                                          |
% | Uses data from:                                                      |
% |     ssD300.mat                                                       |
% |     ssD400.mat                                                       |
% |     initdata.mat                                                     |
% | Saves figures in:                                                    |
% |     p_diff_steadystate.eps                                           |
% |     Q_0_steadystate.eps                                              |
% |     a_A_rho_steadystate.eps                                          |
% |                                                                      |
% | Coded by:                                                            |
% |     Stud. Techn. Eivind Vrlstad,                                    |
% |     Institutt for Energi- og prosessteknikk, NTNU, 2011              |
% 0----------------------------------------------------------------------0

clc
clear all

load('../initdata')
load('ssD300')
load('ssD400')


M3 = M*3+1;

dx1 = wellL/M;
x1 = (0:dx1:wellL)';

dx2 = wellH/M;
x2 = (wellL+dx2:dx2:(wellL+wellH))';

dx3 = riserH/M;
x3 = ((wellL+wellH)+dx3:dx3:(wellL+wellH+riserH))';

x = [x1;x2;x3];


D300 = [ones(2*M,1)*.3;ones(M+1,1)*.3];
D400 = [ones(2*M,1)*.3;ones(M+1,1)*.4];


p_D300 = (p_ss_D300-p_ss_D300(:,1)*ones(1,5))*1E-5;
p_D400 = (p_ss_D400-p_ss_D400(:,1)*ones(1,5))*1E-5;

Q_D300 = Q_ss_D300;
Q_D400 = Q_ss_D400;

a_ss_D300 = sqrt(oilK_0./rho_ss_D300./(1+oilK_0/steelE.*D300*ones(1,5)/steele));
a_ss_D400 = sqrt(oilK_0./rho_ss_D400./(1+oilK_0/steelE.*D400*ones(1,5)/steele));

A_0_ss_D300 = pi/4*D300.^2;
A_0_ss_D400 = pi/4*D400.^2;

A_ss_D300 = A_0_ss_D300*ones(1,5).*oilrho_0./rho_ss_D300.*exp(oilK_0./a_ss_D300.^2.*(1/oilrho_0-1./rho_ss_D300));
A_ss_D400 = A_0_ss_D400*ones(1,5).*oilrho_0./rho_ss_D400.*exp(oilK_0./a_ss_D400.^2.*(1/oilrho_0-1./rho_ss_D400));

Q_0_ss_D300 = rho_ss_D300(1,:)/oilrho_0.*V_ss_D300(1,:).*A_ss_D300(1,:);
Q_0_ss_D400 = rho_ss_D400(1,:)/oilrho_0.*V_ss_D400(1,:).*A_ss_D400(1,:);

disp('Steady-state')
disp(' ')
disp(['a_max = ' num2str(max(a_ss_D300(:,2)))])
disp(['a_min = ' num2str(min(a_ss_D300(:,2)))])
disp(['a_0 = ' num2str(oila_0)])
disp(['A_max = ' num2str(max(A_ss_D300(:,2)))])
disp(['A_min = ' num2str(min(A_ss_D300(:,2)))])
disp(['A_0 = ' num2str(A_0_ss_D300(1,1))])
disp(['rho_max = ' num2str(max(rho_ss_D300(:,2)))])
disp(['rho_min = ' num2str(min(rho_ss_D300(:,2)))])
disp(['rho_0 = ' num2str(oilrho_0)])

i = 0;
for p_top = 20:-5:5
    i = i + 1;
    disp(' ')
    disp(' ')
    disp(['Case ' num2str(i) ', p_top = ' num2str(p_top) ' bar, D_riser = 300 mm'])
    disp(' ')
    disp(['p_well = ' num2str(p_ss_D300(1,i+1)*1E-5) ' bar'])
    disp(['p_head = ' num2str(p_ss_D300(2*M,i+1)*1E-5) ' bar'])
    disp(['p_top = ' num2str(p_ss_D300(M3,i+1)*1E-5) ' bar'])
    disp(' ')
    disp(['V_well = ' num2str(V_ss_D300(1,i+1)) ' m/s'])
    disp(['V_head = ' num2str(V_ss_D300(2*M,i+1)) ' m/s'])
    disp(['V_top = ' num2str(V_ss_D300(M3,i+1)) ' m/s'])
    disp(' ')
    disp(['Q_0 = ' num2str(Q_0_ss_D300(i+1)) ' m^3/s'])
end


i = 0;
for p_top = 20:-5:5
    i = i + 1;
    disp(' ')
    disp(' ')
    disp(['Case ' num2str(i) ', p_top = ' num2str(p_top) ' bar, D_riser = 400 mm'])
    disp(' ')
    disp(['p_well = ' num2str(p_ss_D400(1,i+1)*1E-5) ' bar'])
    disp(['p_head = ' num2str(p_ss_D400(2*M,i+1)*1E-5) ' bar'])
    disp(['p_top = ' num2str(p_ss_D400(M3,i+1)*1E-5) ' bar'])
    disp(' ')
    disp(['V_well = ' num2str(V_ss_D400(1,i+1)) ' m/s'])
    disp(['V_head = ' num2str(V_ss_D400(2*M,i+1)) ' m/s'])
    disp(['V_top = ' num2str(V_ss_D400(M3,i+1)) ' m/s'])
    disp(' ')
    disp(['Q_0 = ' num2str(Q_0_ss_D400(i+1)) ' m^3/s'])
end


figure(1)
clf
subplot(2,1,1)
hold on
plot(x,p_D300(:,2)','k:','LineWidth',1)
plot(x,p_D300(:,3),'k-.','LineWidth',1)
plot(x,p_D300(:,4),'k--','LineWidth',1)
plot(x,p_D300(:,5),'k','LineWidth',1)
hold off
title('Pressure difference from blowout, D = 300 mm')
xlabel('Position')
ylabel('p_{diff} [bar]')
legend( ...
    ['p_{top} = '    num2str(p_ss_D300_top(2)*1e-5) ' bar'], ...
    ['p_{top} = '    num2str(p_ss_D300_top(3)*1e-5) ' bar'], ...
    ['p_{top} = '    num2str(p_ss_D300_top(4)*1e-5) ' bar'], ...
    ['p_{top} = '    num2str(p_ss_D300_top(5)*1e-5) ' bar'])

subplot(2,1,2)
hold on
plot(x,p_D400(:,2)','k:','LineWidth',1)
plot(x,p_D400(:,3),'k-.','LineWidth',1)
plot(x,p_D400(:,4),'k--','LineWidth',1)
plot(x,p_D400(:,5),'k','LineWidth',1)
hold off
title('Pressure difference from blowout, D = 400 mm')
xlabel('Position')
ylabel('p_{diff} [bar]')

print -deps ../plots/p_diff_steadystate

figure(2)
clf
subplot(2,1,1)
hold on
plot(x,Q_D300(:,1),'k','LineWidth',2)
plot(x,Q_D300(:,2)','k:','LineWidth',1)
plot(x,Q_D300(:,3),'k-.','LineWidth',1)
plot(x,Q_D300(:,4),'k--','LineWidth',1)
plot(x,Q_D300(:,5),'k','LineWidth',1)
hold off
title('Volumetric flow, D = 300 mm')
xlabel('Position')
ylabel('Q [m^3/s]')
legend( ...
    ['Q_{0,blowout} = '    num2str(Q_0_ss_D300(1)) ' m/s'], ...
    ['Q_{0,20} = '    num2str(Q_0_ss_D300(2)) ' m/s'], ...
    ['Q_{0,15} = '    num2str(Q_0_ss_D300(3)) ' m/s'], ...
    ['Q_{0,10} = '    num2str(Q_0_ss_D300(4)) ' m/s'], ...
    ['Q_{0,5} = '    num2str(Q_0_ss_D300(5)) ' m/s'], ...
    'location','EastOutside')

subplot(2,1,2)
hold on
plot(x,Q_D400(:,1),'k','LineWidth',2)
plot(x,Q_D400(:,2)','k:','LineWidth',1)
plot(x,Q_D400(:,3),'k-.','LineWidth',1)
plot(x,Q_D400(:,4),'k--','LineWidth',1)
plot(x,Q_D400(:,5),'k','LineWidth',1)
hold off
title('Volumetric flow, D = 400 mm')
xlabel('Position')
ylabel('Q [m^3/s]')
legend( ...
    ['Q_{0,blowout} = '    num2str(Q_0_ss_D400(1)) ' m/s'], ...
    ['Q_{0,20} = '    num2str(Q_0_ss_D400(2)) ' m/s'], ...
    ['Q_{0,15} = '    num2str(Q_0_ss_D400(3)) ' m/s'], ...
    ['Q_{0,10} = '    num2str(Q_0_ss_D400(4)) ' m/s'], ...
    ['Q_{0,5} = '    num2str(Q_0_ss_D400(5)) ' m/s'], ...
    'location','EastOutside')

print -deps ../plots/Q_0_steadystate

figure(3)
clf
hold on
plot(x,a_ss_D300(:,2)/max(a_ss_D300(:,2)),'k','LineWidth',1)
plot(x,A_ss_D300(:,2)/max(A_ss_D300(:,2)),'k:','LineWidth',1)
plot(x,rho_ss_D300(:,2)/max(rho_ss_D300(:,2)),'k-.','LineWidth',1)
%plot(x,p_ss_D300(:,2)/max(p_ss_D300(:,2)),'k--','LineWidth',1)
hold off
title('Variation of a, A and \rho with D = 300 mm, top p_{top} = 20 bar')
xlabel('Position')
legend( ...
    'a/max(a)', ...
    'A/max(A)', ...
    '\rho/max(\rho)', ...
    'location','East')

print -deps ../plots/a_A_rho_steadystate